@@ -1,13 +1,11 @@
 from .version import __version__
 from .LinReg import LinReg, MultLinReg
-from .XrTools import get_anom
+from .XrTools import get_anom,spec_moth_dat,spec_moth_yrmean
 from .UT import convert_lon, reverse_lon
 from .load_sst import load_sst
 from .EOF import EOF
 from .linger_cal import linear_reg, multi_linreg, multi_corr, partial_corr
-
-
-
+from .SigTest import one_mean_test, two_mean_test
 
 __author__ = "Zilu Meng"
 __email__ = "mzll1202@163.com"
\ No newline at end of file
